@@ -1,9 +1,9 @@
 package Finance::Robinhood;
-use 5.010;
+use 5.012;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.01_001";
+our $VERSION = "0.01_002";
 use Moo;
 use HTTP::Tiny '0.056';
 use JSON::Tiny qw[decode_json];
@@ -74,6 +74,7 @@ my %endpoints = (
                 'user/basic_info'         => 'user/basic_info/',
                 'user/employment'         => 'user/employment/',
                 'user/investment_profile' => 'user/investment_profile/',
+                'user/identity_mismatch'  => 'user/identity_mismatch',
                 'watchlists'              => 'watchlists/',
                 'watchlists/bulk_add'     => 'watchlists/%s/bulk_add/'
 );
@@ -92,7 +93,7 @@ my %headers = (
          'Accept-Language' =>
              'en;q=1, fr;q=0.9, de;q=0.8, ja;q=0.7, nl;q=0.6, it;q=0.5',
          'Content-Type' => 'application/x-www-form-urlencoded; charset=utf-8',
-         'X-Robinhood-API-Version' => '1.69.3',
+         'X-Robinhood-API-Version' => '1.70.0',
          'User-Agent' => 'Robinhood/823 (iPhone; iOS 7.1.2; Scale/2.00)'
 );
 sub errors { shift; carp shift; }
@@ -228,6 +229,16 @@ sub investment_profile {
            map { m[user] ? () : ($_ => $data->{$_}) } keys %$data);
 }
 
+sub identity_mismatch {
+    my ($self) = @_;
+    my ($status, $data, $raw)
+        = $self->_send_request('GET',
+                               Finance::Robinhood::endpoint(
+                                                     'user/identity_mismatch')
+        );
+    return $status == 200 ? $self->_paginate($data) : ();
+}
+
 sub accounts {
     my ($self) = @_;
 
@@ -351,77 +362,7 @@ sub quote_price {
     return shift->quote(shift)->[0]{last_trade_price};
 }
 
-sub _place_order {
-    my ($self, $instrument, $quantity, $side, $order_type, $bid_price,
-        $time_in_force, $stop_price)
-        = @_;
-    $time_in_force //= 'gfd';    # Good For Day
-
-#warn Finance::Robinhood::endpoint('orders');
-#warn Finance::Robinhood::endpoint('accounts') . $self->account()->account_number() . '/';
-# Make API Call
-#ddx $instrument;
-    my $rt = $self->_send_request(
-        'GET',
-        Finance::Robinhood::endpoint('orders'),
-        {account => Finance::Robinhood::endpoint('accounts')
-             . $self->account()->account_number() . '/',
-         instrument    => $instrument->url(),
-         quantity      => $quantity,
-         side          => $side,
-         symbol        => $instrument->symbol(),
-         time_in_force => $time_in_force,
-         trigger       => 'immediate',
-         type          => $order_type,
-         ($order_type eq 'market' ?
-              (    #price => $instrument->bid_price()
-              )
-          : $order_type eq 'limit'     ? (price      => $bid_price)
-          : $order_type eq 'stop_loss' ? (stop_price => $stop_price)
-          : $order_type eq 'stop_limit'
-          ? (price => $bid_price, stop_price => $stop_price)
-          :
-
-            # TODO: stop_limit and stop_loss order types are works in progress
-              ()
-         )
-        }
-    );
-
-    #ddx $rt;
-    return $rt ? Finance::Robinhood::Order->new($rt) : ();
-}
-
-sub place_buy_order {    # TODO: Test and document
-    my ($self, $instrument, $quantity, $order_type, $bid_price) = @_;
-
-# TODO: Make this accept a hash with keys:
-# { bid_price  => $int,
-#   quantity   => $int,
-#   instrument => Finance::Robinhood::Instrument,
-#   # Optional w/ defaults
-#   trigger    => 'gfd' (Good For Day, other options are 'gtc' Good Till Cancelled, 'oco' Order Cancels Other)
-#   time       => 'immediate' (execute trade now or cancel, other option is 'day' where the trade is canceled if not executed by day's end)
-#   type       => 'market'
-# }
-#    def place_sell_order(self, symbol, quantity, order_type=None, bid_price=None):
-#
-    return
-        $self->_place_order($instrument, $quantity, 'buy',
-                            $order_type, $bid_price);
-}
-
-sub place_sell_order {    # TODO: Test and document
-    my ($self, $instrument, $quantity, $order_type, $bid_price) = @_;
-
-#    def place_sell_order(self, symbol, quantity, order_type=None, bid_price=None):
-#
-    return
-        $self->_place_order($instrument, $quantity, 'sell',
-                            $order_type, $bid_price);
-}
-
-sub order {
+sub locate_order {
     my ($self, $order_id) = @_;
     my $result = $self->_send_request('GET',
                     Finance::Robinhood::endpoint('orders') . $order_id . '/');
@@ -444,22 +385,7 @@ sub list_orders {
     );
     $result // return !1;
     return () if !$result;
-    $result->{previous} =~ m[\?cursor=(.+)$] if defined $result->{previous};
-    my $prev = $1 // ();
-    $result->{next} =~ m[\?cursor=(.+)$] if defined $result->{next};
-    my $next = $1 // ();
-    return {
-          results => [
-              map { Finance::Robinhood::Order->new($_) } @{$result->{results}}
-          ],
-          previous => $prev,
-          next     => $next
-    };
-}
-
-sub cancel_order {
-    my ($self, $order) = @_;
-    return $self->_send_request('GET', $order->_get_cancel(), {});
+    return $self->_paginate($result, 'Finance::Robinhood::Order');
 }
 
 # Methods under construction
@@ -537,11 +463,18 @@ sub _paginate {    # Paginates results
     my $prev = $1 // ();
     $res->{next} =~ m[\?cursor=(.+)$] if defined $res->{next};
     my $next = $1 // ();
-    return {results => [map { $class->new(%$_, ($self ? (rh => $self) : ())) }
-                            @{$res->{results}}
-            ],
-            previous => $prev,
-            next     => $next
+    return {
+        results => (
+            defined $class ?
+                [
+                map {
+                    $class->new(%$_, ($self ? (rh => $self) : ()))
+                } @{$res->{results}}
+                ]
+            : $res->{results}
+        ),
+        previous => $prev,
+        next     => $next
     };
 }
 
@@ -755,6 +688,10 @@ This method grabs information about the user's current employment status and
 This method grabs answers about the user's investment experience gathered by
 the survey performed during registration.
 
+=head2 C<identity_mismatch( )>
+
+Returns a paginated list of identification information.
+
 =head2 C<accounts( ... )>
 
 Returns a paginated list of Finance::Robinhood::Account objects related to the
@@ -797,28 +734,12 @@ them, use the C<next> or C<previous> values.
 Returns a sample list of top securities as Finance::Robinhood::Instrument
 objects along with C<next> and C<previous> cursor values.
 
-=head2 C<place_buy_order( ... )>
+=head2 C<locate_order( ... )>
 
-    $rh->place_buy_order($instrument, $number, $type);
+    my $order = $rh->locate_order( $order_id );
 
-Puts in an order to buy a given C<$number> of shares of the given
-C<$instrument>. Currently, only C<'market'> type sales have been tested. A
-Finance::Robinhood::Order object is returned if the order was sucessful.
-
-=head2 C<place_sell_order( ... )>
-
-    $rh->place_sell_order($instrument, $number, $type);
-
-Puts in an order to sell a given C<$number> of shares of the given
-C<$instrument>. Currently, only C<'market'> type sales have been tested. A
-Finance::Robinhood::Order object is returned if the order was sucessful.
-
-=head2 C<cancel_order( ... )>
-
-    my $order = $rh->place_sell_order($instrument, $number, $type);
-    $rh->cancel_order( $order ); # Whoops! Nevermind!
-
-Cancels a buy or sell order if called before the order is executed.
+Returns a blessed Finance::Robinhood::Order object related to the about the
+buy or sell order with the given id.
 
 =head2 C<list_orders( ... )>
 
@@ -834,13 +755,6 @@ You'll likely generate more than a hand full of buy and sell orders which
 would generate more than a single page of results. To gather them, use the
 C<next> or C<previous> values.
 
-=head2 C<order( ... )>
-
-    my $order = $rh->order( $order_id );
-
-Returns a Finance::Robinhood::Order object which contains information about an
-order and its status.
-
 =head2 C<quote( ... )>
 
     my %msft = $rh->quote('MSFT');
